API Reference
=============

Data extraction
---------------

.. automodule:: gistim.data_extraction
    :members:
    :undoc-members:
    :show-inheritance:

Conversion to TimML elements
----------------------------

.. automodule:: gistim.elements
    :members:
    :undoc-members:
    :show-inheritance:

TimServer
---------

.. automodule:: gistim.tim_server
    :members:
    :undoc-members:
    :show-inheritance: